@@ -1,3 +1,4 @@
+import os
 import sys
 from dataclasses import dataclass, field
 from typing import IO, Optional, Union
@@ -16,13 +17,6 @@ class StreamHandler:
     def _open(self) -> IO[str]:
         return self.stream
 
-    def flush(self) -> None:
-        try:
-            if self.stream and hasattr(self.stream, 'flush'):
-                self.stream.flush()
-        except Exception:
-            pass
-
     def close(self) -> None:
         pass
 
@@ -37,6 +31,14 @@ class FileHandler(StreamHandler):
 
     stream: Optional[IO[str]] = field(init=False, default=None)  # type: ignore
 
+    def __post_init__(self) -> None:
+        self.mkdir()
+
+    def mkdir(self) -> None:
+        fp = self.filename.split('/')
+        if len(fp) > 1:
+            os.makedirs('/'.join(fp[:-1]), mode=0o755, exist_ok=True)
+
     def _open(self) -> IO[str]:
         if self.stream is None:
             self.stream = open(
